==> java-1.2.3.tar.gz: java-1.2.3/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/service/OiosiServiceSenderFault.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Sgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */

package dk.gov.oiosi.test.service;

import org.apache.axiom.om.OMElement;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import dk.gov.oiosi.communication.OiosiMessage;
import dk.gov.oiosi.exception.MainException;

/**
 * Service which returns application soap fault.
 */
public class OiosiServiceSenderFault extends OiosiService {

    /**
     * local log.
     */
    private static final Log log = LogFactory.getLog(OiosiServiceSenderFault.class);

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.service.OiosiService#requestRespond(dk.gov.oiosi.communication.OiosiMessage)
     */
    public OiosiMessage requestRespond(OiosiMessage message) throws MainException {
        log.error("OIOSI Sender Fault Start");
        OMElement document = message.getMessageXml().getOMDocument();
        String messageId = message.getMessageId();
        invokeCounter++;

        if (document == null) {
            log.error("OIOSI Sender Fault - Test Service Received empty document : total/confirm/timeout/cancel/abort = "
                    + invokeCounter + "/" + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId);
        } else {
            log.error("OIOSI Sender Fault - Test Service received DOCUMENT : total/confirm/timeout/cancel/abort = " + invokeCounter
                    + "/" + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId + " :: "
                    + document.getLocalName());
        }

        MainException e = new MainException("Allways return Sender Fault");
        e.setReceiverError(false);
        e.setSoapFaultAction("InteropSenderFault");

        throw e;

    }

}

==> java-2.0.0.tar.gz: java-2.0.0/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/service/OiosiServiceSenderFault.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.service;

import dk.gov.oiosi.communication.OiosiMessage;
import dk.gov.oiosi.exception.MainException;
import org.apache.axiom.om.OMElement;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Service which returns application soap fault.
 */
public class OiosiServiceSenderFault extends OiosiService {

    /**
     * local log.
     */
    private static final Log log = LogFactory.getLog(OiosiServiceSenderFault.class);

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.service.OiosiService#requestRespond(dk.gov.oiosi.communication.OiosiMessage)
     */
    public OiosiMessage requestRespond(OiosiMessage message) throws MainException {
        log.error("OIOSI Sender Fault Start");
        OMElement document = message.getMessageXml().getOMDocument();
        String messageId = message.getMessageIdentifier();
        invokeCounter++;

        if (document == null) {
            log.error("OIOSI Sender Fault - Test Service Received empty document : total/confirm/timeout/cancel/abort = "
                    + invokeCounter + "/" + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId);
        } else {
            log.error("OIOSI Sender Fault - Test Service received DOCUMENT : total/confirm/timeout/cancel/abort = " + invokeCounter
                    + "/" + confirmCounter + "/" + timeoutCounter + "/" + faultedCounter + " : " + messageId + " :: "
                    + document.getLocalName());
        }

        MainException e = new MainException("Always return Sender Fault");
        e.setReceiverError(false);
        e.setSoapFaultAction("InteropSenderFault");

        throw e;
    }
}
